<?php

namespace Drupal\viewer\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'ViewerBlock' block.
 *
 * @Block(
 *  id = "viewer",
 *  admin_label = @Translation("Viewer"),
 * )
 */
class ViewerBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $viewer = '';
    if (!empty($this->configuration['viewer_reference'])) {
      if ($exists = \Drupal::entityTypeManager()->getStorage('viewer')->load($this->configuration['viewer_reference'])) {
        $viewer = $exists;
      }
    }
    $form['viewer_reference'] = [
      '#title' => $this->t('Viewer'),
      '#type' => 'entity_autocomplete',
      '#target_type' => 'viewer',
      '#default_value' => $viewer,
      '#selection_handler' => 'default',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['viewer_reference'] = $form_state->getValue('viewer_reference');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];
    if (empty($this->configuration['viewer_reference'])) {
      return $build;
    }
    if ($viewer = \Drupal::entityTypeManager()->getStorage('viewer')->load($this->configuration['viewer_reference'])) {
      if ($plugin = $viewer->getViewerPlugin()) {
        $plugin->setViewer($viewer);
        if ($viewer->isPublished()) {
          if ($plugin->requirementsAreMet()) {
            $build['viewer'] = $plugin->getRenderable();
          }
          else {
            $build['viewer'] = ['#markup' => $this->t('Required conditions are not met for the %name', ['%name' => $viewer->label()])];
          }
        }
        else {
          $build['viewer'] = ['#markup' => $this->t('%name is inactive', ['%name' => $viewer->label()])];
        }
        if (!empty($build['viewer'])) {
          if ($viewer_source = $viewer->getViewerSource()) {
            $build['viewer']['#cache']['tags'] = ['viewer_source:' . $viewer_source->id(), 'viewer:' . $viewer->id()];
          }
          else {
            $build['viewer']['#cache']['tags'] = ['viewer:' . $viewer->id()];
          }
        }
      }
    }
    return $build;
  }

}
