<?php

namespace Drupal\viewer\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'viewer' formatter.
 *
 * @FieldFormatter(
 *   id = "viewer",
 *   label = @Translation("Viewer"),
 *   field_types = {
 *     "viewer"
 *   }
 * )
 */
class ViewersFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];
    foreach ($items as $delta => $item) {
      if ($viewer = \Drupal::entityTypeManager()->getStorage('viewer')->load($item->target_id)) {
        if ($plugin = $viewer->getViewerPlugin()) {
          $plugin->setViewer($viewer);
          if ($viewer->isPublished()) {
            if ($plugin->requirementsAreMet()) {
              $element[$delta] = $plugin->getRenderable();
            }
            else {
              $element[$delta] = ['#markup' => $this->t('Required conditions are not met for the %name', ['%name' => $viewer->label()])];
            }
          }
          else {
            $element[$delta] = ['#markup' => $this->t('%name is inactive', ['%name' => $viewer->label()])];
          }
          if (!empty($element[$delta])) {
            if ($viewer_source = $viewer->getViewerSource()) {
              $element[$delta]['#cache']['tags'] = ['viewer_source:' . $viewer_source->id(), 'viewer:' . $viewer->id()];
            }
            else {
              $element[$delta]['#cache']['tags'] = ['viewer:' . $viewer->id()];
            }
          }
        }
      }
    }
    return $element;
  }

}
