<?php

namespace Drupal\viewer\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'viewer_widget' widget.
 *
 * @FieldWidget(
 *   id = "viewer",
 *   label = @Translation("Viewer"),
 *   field_types = {
 *     "viewer"
 *   }
 * )
 */
class ViewersWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $storage = \Drupal::entityTypeManager()->getStorage('viewer');
    $ids = $storage->getQuery()
      ->sort('created', 'DESC')
      ->accessCheck(TRUE)
      ->execute();
    $entities = $storage->loadMultiple($ids);
    $options = [];
    foreach ($entities as $entity) {
      $status = $entity->isPublished() ? 'Active' : 'Inactive';
      $options[$entity->id()] = $entity->label() . ' (' . $this->t($status) . ')';
    }
    $element['target_id'] = [
      '#title' => $this->t('Viewer'),
      '#type' => 'select',
      '#empty_option' => $this->t('- Select Viewer -'),
      '#options' => $options,
      '#default_value' => isset($items[$delta]->target_id) ? $items[$delta]->target_id : '',
    ];
    return $element;
  }

}
