<?php

namespace Drupal\viewer\Services;

use League\Flysystem\Ftp\FtpAdapter;
use League\Flysystem\Ftp\FtpConnectionOptions;
use League\Flysystem\Filesystem;
use League\Flysystem\PhpseclibV3\SftpConnectionProvider;
use League\Flysystem\PhpseclibV3\SftpAdapter;
use League\Flysystem\UnixVisibility\PortableVisibilityConverter;

/**
 * FtpSftp service to process FTP/SFTP connection.
 *
 * @ingroup viewer
 */
class FtpSftp {

  protected $fileSystem;

  /**
   * Establish FTP connection.
   */
  public function ftp($settings) {
    $adapter = new FtpAdapter(
      FtpConnectionOptions::fromArray([
        'host' => !empty($settings['host']) ? $settings['host'] : '', // required
        'root' => !empty($settings['root']) ? $settings['root'] : '/', // required
        'username' => !empty($settings['username']) ? $settings['username'] : '', // required
        'password' => !empty($settings['password']) ? $settings['password'] : NULL, // required
        'port' => !empty($settings['port']) ? (int) $settings['port'] : 21,
        'ssl' => !empty($settings['ssl']),
        'timeout' => !empty($settings['timeout']) ? (int) $settings['timeout'] : 90,
        'utf8' => false,
        'passive' => true,
        'transferMode' => FTP_BINARY,
        'systemType' => null, // 'windows' or 'unix'
        'ignorePassiveAddress' => null, // true or false
        'timestampsOnUnixListingsEnabled' => false, // true or false
        'recurseManually' => true // true 
      ])
    );
    $this->fileSystem = new Filesystem($adapter);
  }

  /**
   * Establish SFTP connection.
   */
  public function sftp($settings) {
    $adapter = new SftpAdapter(
      new SftpConnectionProvider(
        $settings['host'], // host (required)
        $settings['username'], // username (required)
        // password (optional, default: null) set to null if privateKey is used
        (empty($settings['use_private_key']) ? $settings['password'] : NULL),
        // private key (optional, default: null) can be used instead of password, set to null if password is set
        (!empty($settings['password']) ? NULL : $settings['private_key']),
        // passphrase (optional, default: null), set to null if privateKey is not used or has no passphrase
        (!empty($settings['use_private_key']) ? $settings['passphrase'] : NULL),
        (!empty($settings['port']) ? $settings['port'] : 2222), // port (optional, default: 22)
        !empty($settings['user_agent']), // use agent (optional, default: false)
        (!empty($settings['timeout']) ? $settings['timeout'] : 30), // timeout (optional, default: 10)
        (!empty($settings['maxtries']) ? $settings['maxtries'] : 10) // max tries (optional, default: 4)
      ),
      (!empty($settings['root_path']) ? $settings['root_path'] : '/'), // root path (required)
      PortableVisibilityConverter::fromArray([
        'file' => [
          'public' => 0640,
          'private' => 0604,
        ],
        'dir' => [
          'public' => 0740,
          'private' => 7604,
        ],
      ])
    );
    $this->fileSystem = new Filesystem($adapter);
  }

  /**
   * Download a file from a specified path.
   */
  public function downloadFile($path) {
    try {
      return $this->fileSystem->read($path);
    }
    catch (\Exception $e) {
      \Drupal::logger('viewer')->error($e->getMessage());
    }
  }

}
