<?php

namespace Drupal\viewer\Services;

use GuzzleHttp\Client;
use Drupal\Core\Mail\MailManager;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\viewer\Event\ViewerEventType;
use Drupal\viewer\Event\ViewerEvent;

/**
 * Notifications service.
 *
 * @ingroup viewer
 */
class Notifications {

  protected $loggerFactory;
  protected $httpClient;
  protected $mailManager;

  public function __construct(LoggerChannelFactoryInterface $logger_factory, Client $http_client, MailManager $mail_manager) {
    $this->loggerFactory = $logger_factory;
    $this->httpClient = $http_client;
    $this->mailManager = $mail_manager;
  }

  /**
   * Send a message to a Slack channel.
   */
  public function pushSlack(ViewerEvent $event) {
    $entity = $event->getEntity();
    if ($event->validateType('success') && $event->getEventType() == ViewerEventType::IMPORT_SUCCESS) {
      $message = t('Success: @label successfully imported', ['@label' => $entity->label()]);
    }
    if ($event->validateType('failed') && $event->getEventType() == ViewerEventType::IMPORT_FAILED) {
      $message = t('Failed: @label imported failed', ['@label' => $entity->label()]);
    }
    if (!empty($message)) {
      $request = $this->httpClient->post($event->getSlackHookUrl(), ['json' => ['text' => $message]]);
      if ($request->getStatusCode() !== 200) {
        $this->loggerFactory->get('viewer')
          ->warning(t('Unable to send Slack notification for %label', ['%label' => $entity->label()]));
      }
    }
  }

  /**
   * Send a message to a list of email addresses.
   */
  public function pushEmail(ViewerEvent $event) {
    $entity = $event->getEntity();
    $params = [];
    if ($event->validateType('success') && $event->getEventType() == ViewerEventType::IMPORT_SUCCESS) {
      $params['subject'] = t('Success: @label successfully imported', ['@label' => $entity->label()]);
    }
    if ($event->validateType('failed') && $event->getEventType() == ViewerEventType::IMPORT_FAILED) {
      $params['subject'] = t('Failed: @label imported failed', ['@label' => $entity->label()]);
    }
    if (!empty($params['subject'])) {
      $params['message'] = $params['subject'];
      $mailer = $this->mailManager
        ->mail('viewer', 'notification', $event->getEmailAddresses(), 'en', $params, NULL, TRUE);
      if ($mailer['result'] !== TRUE) {
        $this->loggerFactory->get('viewer')
          ->warning(t('Unable to send Email notification for %label', ['%label' => $entity->label()]));
      }
    }
  }

}
